==> qtify_0.0.1-3.tar.gz: qtify-0.0.1/translations/qtify_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fi" sourcelanguage="en">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <source>MainWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="393"/>
        <source>Playlist</source>
        <translation type="unfinished">Soittolista</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <source>Artist</source>
        <translation type="unfinished">Artisti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>Album</source>
        <translation type="unfinished">Albumi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="311"/>
        <source>Rating</source>
        <translation type="unfinished">Lukema</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="398"/>
        <source>Search</source>
        <translation type="unfinished">Etsi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>Recent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="151"/>
        <source>Username</source>
        <translation type="unfinished">Käyttäjänimi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>Password</source>
        <translation type="unfinished">Salasana</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>Login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="276"/>
        <source>Show</source>
        <translation type="unfinished">Näytä</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="291"/>
        <source>Title</source>
        <translation type="unfinished">Kappaleen nimi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="306"/>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Play/Pause</source>
        <translation type="unfinished">Play/Pause</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="57"/>
        <source>Incorrect credentials entered
please try again.</source>
        <translation type="unfinished">Väärä käyttäjänimi tai salasana, yritä uudelleen.</translation>
    </message>
</context>
</TS>

==> qtify_0.0.1-4.tar.gz: qtify-0.0.1/translations/qtify_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fi" sourcelanguage="en">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <source>MainWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="393"/>
        <source>Playlist</source>
        <translation type="unfinished">Soittolista</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <source>Artist</source>
        <translation type="unfinished">Artisti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>Album</source>
        <translation type="unfinished">Albumi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="311"/>
        <source>Rating</source>
        <translation type="unfinished">Lukema</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="398"/>
        <source>Search</source>
        <translation type="unfinished">Etsi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>Recent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="151"/>
        <source>Username</source>
        <translation type="unfinished">Käyttäjänimi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>Password</source>
        <translation type="unfinished">Salasana</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>Login</source>
        <translation type="unfinished">Kirjaudu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="276"/>
        <source>Show</source>
        <translation type="unfinished">Näytä</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="291"/>
        <source>Title</source>
        <translation type="unfinished">Kappaleen nimi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="306"/>
        <source>Duration</source>
        <translation type="unfinished">Kesto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Play/Pause</source>
        <translation type="unfinished">Play/Pause</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="57"/>
        <source>Incorrect credentials entered
please try again.</source>
        <translation type="unfinished">Väärä käyttäjänimi tai salasana, yritä uudelleen.</translation>
    </message>
</context>
</TS>
